/*
Ascii IO: Converson to and from a stream of ASCII data.
Copyright (C) 2002, Scott Haywood

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/
package scotthaywood.asciiIO;

import java.lang.reflect.*;

/**
 * A <code>Surrogate</code> is needed to create
 * a BasicTypeTranslator.
 * Objects implementing this interface are used 
 * by DataWriter and DataReader in place
 * of objects which they do not know how to handle.
 * <p>
 * In addition to the methods below,
 * implementing classes should have two types of
 * constructors:  one which takes
 * no arguments, and one which takes
 * an object of the target type.
 * Furthermore, the implementing class should have
 * public fields for the data to be written by
 * DataWriter and read by DataReader.
 *
 * @author Scott Haywood
 * @version $Revision: 1.5 $
 */
public interface Surrogate extends AsciiIO.Externalizable {
	
	/**
	 * Returns the target type.
	 */
	public Class getTargetType();

	/**
	 * Creates and returns the target object.
	 */
	public Object createTarget();
}
