/*
Ascii IO: Converson to and from a stream of ASCII data.
Copyright (C) 2002, Scott Haywood

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/
package scotthaywood.asciiIO;


/**
	The <code>TypeTranslator</code> interface is used as part
	of the scheme to translate
	classes of which DataWriter and DataReader do not have a
	built-in knowledge.
	<p>
	The target type is the class of object to be read or written.
	The surrogate is written or read in place of the target object.
	<p>
	BasicTypeTranslator is one implementation of this
	interface.
 *
 * @author Scott Haywood
 * @version $Revision: 1.6 $
*/
public interface TypeTranslator {

	/**
	 * Returns an array of types supported by this
	 * <code>TypeTranslator</code>.
	 */
	public Class[] getTargetTypes();

	//public Object createEmptySurrogate(Class targetType);

	/**
	 * Returns the surrogate type for a given target type.
	 */
	public Class getSurrogateType(Class targetType);

	/**
	 * Creates and returns the surrogate object for a given target.
	 */
	public Object createSurrogate(Object target);

	/**
	 * Creates a target object from a given surrogate.
	 * @param	cls		the desired type of target
	 * @param	surrogate	the surrogate object
	 * @returns an object of type <code>cls</code>,
	 * or null if the target type is not supported.
.
	 */
	public Object createTarget(Class cls, Object surrogate);
	
}
