/*
Image Creator: Creates configurable images
Copyright (C) 2002, Scott Haywood

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

package scotthaywood.imageCreator;

import java.awt.Graphics;
import javax.swing.JComponent;
import javax.swing.event.*;
import scotthaywood.imageCreator.*;

/**
 * <code>Module</code> is a superclass for
 * classes that can be dynamically loaded and configured
 * using <code>Conf</code>.
 * <p>
 * Every <code>Module</code> has a configuration
 * object that can be retrieved or set.
 * @see Conf
 *
 * @author Scott Haywood
 * @version $Revision: 1.6 $
 */
abstract public class Module extends JComponent {


	/**
	 * Gets the configuration object for this module.
	 * If getConfig() returns null, it means the
	 * the Module never has a ModuleConfig object.
	 * @returns the configuration object
	 * @see #setConfig
	 */
	abstract public ModuleConfig getConfig();

	/**
	 * Sets the configuration object for this module.
	 * @param	mc	the new configuration object
	 * @see #getConfig
	 */
	abstract public void setConfig(ModuleConfig mc);


    // state change code copied from some javax.swing classes:

    protected EventListenerList listenerList = new EventListenerList();
    protected transient ChangeEvent changeEvent;

	/**
     * Adds a <code>ChangeListener</code>.
     * @param l the listener to be added
     */
    public void addChangeListener(ChangeListener l) {
        listenerList.add(ChangeListener.class, l);
    }

    /**
     * Removes a ChangeListener.
     * @param l the listener to be removed
     */
    public void removeChangeListener(ChangeListener l) {
        listenerList.remove(ChangeListener.class, l);
    }

	/**
     * Notifies all listeners that have registered interest for
     * notification on this event type.  The event instance
     * is lazily created using the parameters passed into
     * the fire method.
     * @see EventListenerList
     */
    protected void fireStateChanged() {
        // Guaranteed to return a non-null array
        Object[] listeners = listenerList.getListenerList();
        // Process the listeners last to first, notifying
        // those that are interested in this event
        for (int i = listeners.length-2; i>=0; i-=2) {
            if (listeners[i]==ChangeListener.class) {
                // Lazily create the event:
                if (changeEvent == null)
                    changeEvent = new ChangeEvent(this);
                ((ChangeListener)listeners[i+1]).stateChanged(changeEvent);
            }
        }
    }

    //	
	protected void perror(String s) {
		System.err.println(s);
	}

}
