/*
Image Creator: Creates configurable images
Copyright (C) 2002, Scott Haywood

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

package scotthaywood.imageCreator;

import java.awt.Font;
import java.awt.Color;
import java.util.*;
import scotthaywood.asciiIO.*;
//import scotthaywood.imageCreator.*;

/**
 * <code>ModuleConfig</code> is the superclass for all
 * configuration objects of modules.
 * It provides protected methods for maintaining a map
 * of translatable types and their translators.
 * @see ImageModuleConfig
 * @see AsciiIO.HasTranslatableFields
 *
 * @author Scott Haywood
 * @version $Revision: 1.7 $
 */
abstract public class ModuleConfig implements AsciiIO.HasTranslatableFields {

	private HashMap typeMap = new HashMap();
	
	/**
	 * Adds to the list of type-translators.
	 * @param	t	a type-translator
	 * @see #addTypeTranslators
	 * @see #addTypeTranslator(Surrogate)
	 */
	protected void addTypeTranslator(TypeTranslator t) {
		Class[] types = t.getTargetTypes();
		for (int i=0; i<types.length; i++) {
			typeMap.put(types[i], t);
		}
	}
	
	/**
	 * Adds to the list of type-translators.
	 * @param	tt	an array of type-translator
	 * @see #addTypeTranslator
	 */
	protected void addTypeTranslators(TypeTranslator[] tt) {
		for (int i=0; i<tt.length; i++) {
			addTypeTranslator(tt[i]);
		}
	}
	
	/**
	 * Adds to the list of type-translators.
	 * @param	s	a Surrogate object
	 * @see #addTypeTranslator
	 */
	
	protected void addTypeTranslator(Surrogate s) {
		addTypeTranslator(new BasicTypeTranslator(s));
	}
	
	/**
	 * Gets the translator for a given target type.
	 * Provides implementation of <code>TypeTranslatorMap</code>.
	 * @param	cls	the target class
	 * @returns the translator
	 */
	public TypeTranslator getTypeTranslator(Class cls) {
		return (TypeTranslator) typeMap.get(cls);
	}
}
