/*
Image Creator: Creates configurable images
Copyright (C) 2002, Scott Haywood

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

package scotthaywood.imageCreator;

import scotthaywood.imageCreator.SimpleColor;
import scotthaywood.asciiIO.TypeTranslator;

/**
 * <code>SimpleColorTranslator</code> provides a
 * translation between SimpleColor and a surrogate type.
 * @see AsciiIO
 * @see SimpleColor
 * @see TypeTranslator
 *
 * @author Scott Haywood
 * @version $Revision: 1.5 $
 */
public class SimpleColorTranslator implements TypeTranslator {

	private Class targetType = SimpleColor.class;
	
    /**
	 * Returns an array of types supported by this
	 * <code>TypeTranslator</code>.
	 */
	public Class[] getTargetTypes() {
		return new Class[] { targetType };
	}
	
	/**
	 * Returns the surrogate type for a given target type.
	 * @param	targetType	the target type; must be SimpleColor.class.
	 */
	public Class getSurrogateType(Class targetType) {
		return String.class;
	}
	
	/**
	 * Creates and returns the surrogate object for a given target.
	 * @param	target	the target, which must be of type SimpleColor.
	 */
	public Object createSurrogate(Object target) {
		int v = ((SimpleColor) target).getRGB();
		//dpl("color = " + v);
		/*
			Note that Color(int) and SimpleColor(int)
			add high-order bits to the integer parameter.
			The expression
				(new Color(x)).getRGB() == (x | (0xff << 24))
			where x is an integer RGB value, is always true.
			Return the getRGB() value as an unsigned hex number.
		*/
		return "0x" + Integer.toHexString(v);
	}
	
	/**
	 * Creates a target object from a given surrogate.
	 * @param	cls		the desired type of target
	 * @param	surrogate	the surrogate object.
	 *  Must be a string representation of the RGB color value.
	 * @returns an object of type <code>cls</code>,
	 * or null if the target type is not supported.
	 */
	public Object createTarget(Class cls, Object surrogate) {
		if (cls != SimpleColor.class) return null;
		//dpl("surrogate = " + (String)surrogate);
		int i = Long.decode((String) surrogate).intValue();
		//dpl("surrogate = " + (String)surrogate +
		//                   ", i=" + i);
		
		
		return new SimpleColor(i, true);
	}
	
    private String dplcn;
	private void dpl(String s) {
		if (dplcn == null) {
			String cn = getClass().getName();
			dplcn = cn.substring(cn.lastIndexOf('.')+1);
		}
		System.err.println(dplcn + ": " + s);
	}
}
