/*
Image Creator: Creates configurable images
Copyright (C) 2002, Scott Haywood

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

package scotthaywood.imageCreator;

import scotthaywood.imageCreator.SimpleFont;
import scotthaywood.asciiIO.Surrogate;

/**
 * <code>SimpleFontSurrogate</code> is a Surrogate type,
 * used to represent a <code>SimpleFont</code> so that it
 * can be read/written using the AsciiIO classes.
 * @see Surrogate
 * @see SimpleFont
 * @see AsciiIO
 *
 * @author Scott Haywood
 * @version $Revision: 1.4 $
 */
public class SimpleFontSurrogate implements Surrogate {

	Class targetType = SimpleFont.class;
	
	// these fields must be public
	public String name;
	public int style;
	public int size;
	
	/**
	 * Constructs a SimpleFontSurrogate object.
	 */
	public SimpleFontSurrogate() {}
	
	
	/**
	 * Constructs a SimpleFontSurrogate object.
	 * @param	target	the SimpleFont for which this is a surrogate.
	 */
	public SimpleFontSurrogate(SimpleFont target) {
		SimpleFont f = target;
		name = f.getName();
		style = f.getStyle();
		size = f.getSize();
		//System.err.println("created " + this);
	}
	
	/**
	 * Returns the target type for this surrogate.
	 */
	public Class getTargetType() { return targetType; }
	
	/**
	 * Creates and returns the target object.
	 */
	public Object createTarget() {
		SimpleFont f = new SimpleFont(name, style, size);
		//System.err.println("created target " + f);
		return f;
	}
	
	/**
	 * Creates and returns a string representation of this object.
	 */
	public String toString() {
		return getClass().getName() + "[" +
			"name=" + name + ", " +
			"style=" + style + ", " +
			"size=" + size +
			"]";
	}
}
