/*
Copyright (C) 2002, Scott Haywood

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

package scotthaywood.ui;

import java.awt.Color;
import java.awt.Component;
import java.awt.Graphics;
import javax.swing.Icon;

/**
 * This implementation of <code>javax.swing.Icon</code>
 * displays as a rectangle of one color.
 *
 * @author Scott Haywood
 * @version $Revision: 1.3 $
 */
public class ColorIcon implements Icon {

	// --------------------------------------------------
	// methods implementing Icon
	//
	public int getIconWidth() { return iwidth; }
	public int getIconHeight() { return iheight; }
	public void paintIcon(Component c, Graphics g, int w, int h) {
		Color sav = g.getColor();
		g.setColor(color);
		g.fillRect(0,0,iwidth,iheight);
		g.setColor(sav);
	}
	// --------------------------------------------------
	
	private int iwidth, iheight;
	
	/**
	 * Constructs an icon of a given size and color.
	 * @param	w	width in pixels.
	 * @param	h	height in pixels.
	 * @param	c	the color.
	 */
	public ColorIcon(int w, int h, Color c) {
		color = c;
		iwidth = w;
		iheight = h;
	}
	
	private Color color = Color.black;
	
	/**
	 * Returns the color.
	 * @return	the color that this icon displays.
	 * @see #setColor
	 */
	public Color getColor() { return color; }
	
	/**
	 * Sets the color.
	 * @param	c	The new color for the icon to display.
	 * @see #getColor
	 */
	public void setColor(Color c) { color = c; }
	
	
}
