/*
Copyright (C) 2002, Scott Haywood

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

import java.awt.*;
import java.beans.*;
import java.awt.event.*;
import java.awt.geom.*;
import javax.swing.*;
import scotthaywood.ui.PointSelector;


/**
 * This program is a test of the PointSelector class.
 *
 * It displays an image framed by a PointSelector.
 * A small circle within the image remains centered
 * on whatever point is chosen using the PointSelector.
 *
 * @author Scott Haywood
 * @version $Revision: 1.5 $
 */
class PointSelectorTest {

	private static void dpl(String s) {
		System.out.println(s);
	}
	abstract static class Comp extends JComponent {
		abstract public void setPoint(Point p);
	}
	public static void main(String[] args) {

		// create a blank panel
		final Comp panel = new Comp() {

			Point point = new Point();

			public void paintComponent(Graphics g) {
				int w = getWidth();
				int h = getHeight();
				//dpl("paint target !!!!!!!!!!!!!");

				Color c = new Color(128,128,32);
				g.setColor(c);
				g.fillRect(0,0,w,h);

				c = new Color(128,128,128);
				g.setColor(c);
				g.fillRect(w/3, h/3, w/3, h/3);
				g.setColor(Color.black);
				g.drawRect(w/3, h/3, w/3, h/3);

				g.setColor(Color.white);
				g.drawLine(0,0,w,h);
				g.drawLine(w,0,0,h);

				g.setColor(Color.red);
				g.translate(point.x, point.y);
				g.drawOval(-8, -8, 16, 16);
			}
			public void setPoint(Point p) {
				point.setLocation(p);
			}
		};
		panel.setSize(200,200);

		// create the object to be tested
		final PointSelector ps = new PointSelector(panel);
		dpl("ps size = "+ps.getSize());
		panel.setPoint(ps.getPoint()); // should be center
		ps.setReportingPointOnResize(true);

		// create buttons
		final JCheckBox enable = new JCheckBox("enable", true);
		JButton quit = new JButton("quit");

		// create a container, add widgets
		Box box = Box.createVerticalBox();
		box.add(new JLabel("This is a test"));
		box.add(ps);
		box.add(enable);
		box.add(quit);

		// add to main frame
		final JFrame f = new JFrame(ps.getClass().getName() + " test");
		f.getContentPane().setLayout(new BorderLayout());
		f.getContentPane().add(box, BorderLayout.CENTER);

		// add event handlers
		enable.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				ps.setEnabled(enable.isSelected());
			}
		});
		quit.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) { System.exit(0); }
		});
		f.addWindowListener(new WindowAdapter() {
			public void windowClosing(WindowEvent e) {
				dpl("closing");
				f.setVisible(false);
				f.dispose();
				System.exit(0);
			}
		});
		ps.addPropertyChangeListener(new PropertyChangeListener() {
			 public void propertyChange(PropertyChangeEvent pce) { 
			 	dpl("property change: name=" + pce.getPropertyName() +
				    ", new value=" + pce.getNewValue());
			 	if (pce.getPropertyName().equals("point")) {
					panel.setPoint((Point)pce.getNewValue());
				}
			 	
			 }
		});

		// position the frame
		f.pack();
        Dimension d = Toolkit.getDefaultToolkit().getScreenSize();
        f.setLocation(d.width/2 - f.getWidth()/2,
		              d.height/2 - f.getHeight()/2);
		dpl("panel size = " + panel.getSize());
		f.show();

	}
}

